@@ -44,4 +44,14 @@ from .urdf import (
     URDFSaveValidationError,
     URDFMalformedError,
     URDFUnsupportedError,
+    filename_handler_null,
+    filename_handler_ignore_directive,
+    filename_handler_ignore_directive_package,
+    filename_handler_add_prefix,
+    filename_handler_absolute2relative,
+    filename_handler_relative,
+    filename_handler_relative_to_urdf_file,
+    filename_handler_relative_to_urdf_file_recursive,
+    filename_handler_meta,
+    filename_handler_magic,
 )
